==> jc-1.4.0.tar.gz: java/util/prefs/InvalidPreferencesFormatException.h <==
// public class java.util.prefs.InvalidPreferencesFormatException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 1751435027ec6c6f java_util_prefs_InvalidPreferencesFormatException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_util_prefs_InvalidPreferencesFormatException_H_
#define _JC_java_util_prefs_InvalidPreferencesFormatException_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_io_ObjectOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$sub_refs	_jc_java_util_prefs_InvalidPreferencesFormatException$sub_refs;
typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$sub_nonrefs	_jc_java_util_prefs_InvalidPreferencesFormatException$sub_nonrefs;
typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$refs	_jc_java_util_prefs_InvalidPreferencesFormatException$refs;
typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$nonrefs	_jc_java_util_prefs_InvalidPreferencesFormatException$nonrefs;
typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$object	_jc_java_util_prefs_InvalidPreferencesFormatException$object;

typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$fields_struct	_jc_java_util_prefs_InvalidPreferencesFormatException$fields_struct;
typedef const struct _jc_java_util_prefs_InvalidPreferencesFormatException$vmethods	_jc_java_util_prefs_InvalidPreferencesFormatException$vmethods;
typedef const struct _jc_java_util_prefs_InvalidPreferencesFormatException$vtable	_jc_java_util_prefs_InvalidPreferencesFormatException$vtable;
typedef const struct _jc_java_util_prefs_InvalidPreferencesFormatException$vtype	_jc_java_util_prefs_InvalidPreferencesFormatException$vtype;

// Class fields structure
struct _jc_java_util_prefs_InvalidPreferencesFormatException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_prefs_InvalidPreferencesFormatException$fields_struct _jc_java_util_prefs_InvalidPreferencesFormatException$class_fields;

// Constructors
extern void _jc_java_util_prefs_InvalidPreferencesFormatException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_util_prefs_InvalidPreferencesFormatException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_java_util_prefs_InvalidPreferencesFormatException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods
extern void _jc_java_util_prefs_InvalidPreferencesFormatException$method$readObject$a94c095c21a0b9e8(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_io_ObjectInputStream$object *);
extern void _jc_java_util_prefs_InvalidPreferencesFormatException$method$writeObject$6755db4c37bbfbcf(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_io_ObjectOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_prefs_InvalidPreferencesFormatException$method_info$readObject$a94c095c21a0b9e8;
extern _jc_method _jc_java_util_prefs_InvalidPreferencesFormatException$method_info$writeObject$6755db4c37bbfbcf;

// Virtual methods structure
struct _jc_java_util_prefs_InvalidPreferencesFormatException$vmethods {
	void	(*readObject$a94c095c21a0b9e8)(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_io_ObjectInputStream$object *);
	void	(*writeObject$6755db4c37bbfbcf)(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_io_ObjectOutputStream$object *);
};

// Vtable
struct _jc_java_util_prefs_InvalidPreferencesFormatException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_util_prefs_InvalidPreferencesFormatException$vmethods	java_util_prefs_InvalidPreferencesFormatException;
};

// Vtype
struct _jc_java_util_prefs_InvalidPreferencesFormatException$vtype {
	_jc_type			type;
	_jc_java_util_prefs_InvalidPreferencesFormatException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_prefs_InvalidPreferencesFormatException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_prefs_InvalidPreferencesFormatException$refs {
    _jc_java_util_prefs_InvalidPreferencesFormatException$sub_refs	java_util_prefs_InvalidPreferencesFormatException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_prefs_InvalidPreferencesFormatException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_prefs_InvalidPreferencesFormatException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_util_prefs_InvalidPreferencesFormatException$sub_nonrefs	java_util_prefs_InvalidPreferencesFormatException;
};

// Object instance structure
struct _jc_java_util_prefs_InvalidPreferencesFormatException$object {
	_jc_java_util_prefs_InvalidPreferencesFormatException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_prefs_InvalidPreferencesFormatException$vtype	*vtype;
	_jc_java_util_prefs_InvalidPreferencesFormatException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_prefs_InvalidPreferencesFormatException$vtype _jc_java_util_prefs_InvalidPreferencesFormatException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_prefs_InvalidPreferencesFormatException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_prefs_InvalidPreferencesFormatException$class_object;

#endif	/* _JC_java_util_prefs_InvalidPreferencesFormatException_H_ */

==> jc-1.4.6.tar.gz: java/util/prefs/InvalidPreferencesFormatException.h <==
// public class java.util.prefs.InvalidPreferencesFormatException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 1751435027ec6c6f java_util_prefs_InvalidPreferencesFormatException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_util_prefs_InvalidPreferencesFormatException_H_
#define _JC_java_util_prefs_InvalidPreferencesFormatException_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_io_ObjectOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$sub_refs	_jc_java_util_prefs_InvalidPreferencesFormatException$sub_refs;
typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$sub_nonrefs	_jc_java_util_prefs_InvalidPreferencesFormatException$sub_nonrefs;
typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$refs	_jc_java_util_prefs_InvalidPreferencesFormatException$refs;
typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$nonrefs	_jc_java_util_prefs_InvalidPreferencesFormatException$nonrefs;
typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$object	_jc_java_util_prefs_InvalidPreferencesFormatException$object;

typedef struct _jc_java_util_prefs_InvalidPreferencesFormatException$fields_struct	_jc_java_util_prefs_InvalidPreferencesFormatException$fields_struct;
typedef const struct _jc_java_util_prefs_InvalidPreferencesFormatException$vmethods	_jc_java_util_prefs_InvalidPreferencesFormatException$vmethods;
typedef const struct _jc_java_util_prefs_InvalidPreferencesFormatException$vtable	_jc_java_util_prefs_InvalidPreferencesFormatException$vtable;
typedef const struct _jc_java_util_prefs_InvalidPreferencesFormatException$vtype	_jc_java_util_prefs_InvalidPreferencesFormatException$vtype;

// Class fields structure
struct _jc_java_util_prefs_InvalidPreferencesFormatException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_prefs_InvalidPreferencesFormatException$fields_struct _jc_java_util_prefs_InvalidPreferencesFormatException$class_fields;

// Constructors
extern void _jc_java_util_prefs_InvalidPreferencesFormatException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_prefs_InvalidPreferencesFormatException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_prefs_InvalidPreferencesFormatException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_prefs_InvalidPreferencesFormatException$method$readObject$a94c095c21a0b9e8(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_io_ObjectInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_prefs_InvalidPreferencesFormatException$method$writeObject$6755db4c37bbfbcf(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_io_ObjectOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_prefs_InvalidPreferencesFormatException$method_info$readObject$a94c095c21a0b9e8;
extern _jc_method _jc_java_util_prefs_InvalidPreferencesFormatException$method_info$writeObject$6755db4c37bbfbcf;

// Virtual methods structure
struct _jc_java_util_prefs_InvalidPreferencesFormatException$vmethods {
	void	(*readObject$a94c095c21a0b9e8)(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_io_ObjectInputStream$object *) _JC_JCNI_ATTR;
	void	(*writeObject$6755db4c37bbfbcf)(_jc_env *, struct _jc_java_util_prefs_InvalidPreferencesFormatException$object *, struct _jc_java_io_ObjectOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_prefs_InvalidPreferencesFormatException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_util_prefs_InvalidPreferencesFormatException$vmethods	java_util_prefs_InvalidPreferencesFormatException;
};

// Vtype
struct _jc_java_util_prefs_InvalidPreferencesFormatException$vtype {
	_jc_type			type;
	_jc_java_util_prefs_InvalidPreferencesFormatException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_prefs_InvalidPreferencesFormatException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_prefs_InvalidPreferencesFormatException$refs {
    _jc_java_util_prefs_InvalidPreferencesFormatException$sub_refs	java_util_prefs_InvalidPreferencesFormatException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_prefs_InvalidPreferencesFormatException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_prefs_InvalidPreferencesFormatException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_util_prefs_InvalidPreferencesFormatException$sub_nonrefs	java_util_prefs_InvalidPreferencesFormatException;
};

// Object instance structure
struct _jc_java_util_prefs_InvalidPreferencesFormatException$object {
	_jc_java_util_prefs_InvalidPreferencesFormatException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_prefs_InvalidPreferencesFormatException$vtype	*vtype;
	_jc_java_util_prefs_InvalidPreferencesFormatException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_prefs_InvalidPreferencesFormatException$vtype _jc_java_util_prefs_InvalidPreferencesFormatException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_prefs_InvalidPreferencesFormatException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_prefs_InvalidPreferencesFormatException$class_object;

#endif	/* _JC_java_util_prefs_InvalidPreferencesFormatException_H_ */
